==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/c5/c5e59aa632f4bf9def0d20866e20ec7f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Assets/css/user.css */
class __TwigTemplate_58d374d7a1a00139d0e2bfd64a5ac8d4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/* UserBundle */

.profile-details {
    margin-bottom: 20px;
}

.col-user-id, .col-role-id {
    width: 75px;
}

.col-user-avatar {
    width: 75px;
}

.mautic-logo {
    width: 150px;
    margin: 0 auto;
    background: #ffffff;
}

.mautic-logo > svg.mautic-logo-figure .circle {
    fill: #4e5e9e;
}

.mautic-logo > svg.mautic-logo-figure .m,
.mautic-logo > svg.mautic-logo-figure .m-arrow {
      fill: #fdb933;
}

input:-webkit-autofill {
    -webkit-box-shadow: 0 0 0px 1000px white inset;
}

span.input-group-addon i.fa {
    width: 20px;
}

.inline-login .login-form {
    margin: 20px;
}

.accent-color {
    width: 28px;
    height: 28px;
    display: inline-flex;
    cursor: pointer;
}

.accent-color,
.accent-dropdown {
    outline: 2px var(--outline-style) transparent;
    outline-offset: 2px;
    transition: var(--transition-all-productive);
}

input:checked + .accent-color,
.dropdown.open .accent-dropdown {
    outline: 2px var(--outline-style) var(--focus);
    outline-offset: 2px;
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Assets/css/user.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Assets/css/user.css", "/var/www/html/mauticGIT-Test/app/bundles/UserBundle/Assets/css/user.css");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/c5/c5e59aa632f4bf9def0d20866e20ec7f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Assets/css/user.css */
class __TwigTemplate_58d374d7a1a00139d0e2bfd64a5ac8d4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/* UserBundle */

.profile-details {
    margin-bottom: 20px;
}

.col-user-id, .col-role-id {
    width: 75px;
}

.col-user-avatar {
    width: 75px;
}

.mautic-logo {
    width: 150px;
    margin: 0 auto;
    background: #ffffff;
}

.mautic-logo > svg.mautic-logo-figure .circle {
    fill: #4e5e9e;
}

.mautic-logo > svg.mautic-logo-figure .m,
.mautic-logo > svg.mautic-logo-figure .m-arrow {
      fill: #fdb933;
}

input:-webkit-autofill {
    -webkit-box-shadow: 0 0 0px 1000px white inset;
}

span.input-group-addon i.fa {
    width: 20px;
}

.inline-login .login-form {
    margin: 20px;
}

.accent-color {
    width: 28px;
    height: 28px;
    display: inline-flex;
    cursor: pointer;
}

.accent-color,
.accent-dropdown {
    outline: 2px var(--outline-style) transparent;
    outline-offset: 2px;
    transition: var(--transition-all-productive);
}

input:checked + .accent-color,
.dropdown.open .accent-dropdown {
    outline: 2px var(--outline-style) var(--focus);
    outline-offset: 2px;
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Assets/css/user.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Assets/css/user.css", "/var/www/html/production-demo/app/bundles/UserBundle/Assets/css/user.css");
    }
}
